from django.db import models

RESOURCE_STATUS_TOBEACTIVE = 5
RESOURCE_STATUS_ACTIVE = 10
RESOURCE_STATUS_TOBESUSPENDED = 15
RESOURCE_STATUS_SUSPENDED = 20
RESOURCE_STATUS_TOBECLOSED = 25
RESOURCE_STATUS_CLOSED = 30
RESOURCE_STATUSES = (
        (0, 'Created'),
        (RESOURCE_STATUS_TOBEACTIVE, 'ToBeActive'),
        (RESOURCE_STATUS_ACTIVE, 'Active'),
        (RESOURCE_STATUS_TOBESUSPENDED, 'ToBeSuspended'),
        (RESOURCE_STATUS_SUSPENDED, 'Suspended'),
        (RESOURCE_STATUS_TOBECLOSED, 'ToBeClosed'),
        (RESOURCE_STATUS_CLOSED, 'Closed'),
        )

class User(models.Model):
    fullname = models.CharField(max_length=128)
    uname = models.CharField(max_length=32)
    password = models.CharField(max_length=64)
    #email = models.CharField(max_length=256, blank=True)
    created = models.DateTimeField(auto_now_add=True)
    modified = models.DateTimeField(auto_now=True)
    expire = models.DateTimeField(blank=True, null=True)
    status = models.IntegerField(choices = RESOURCE_STATUSES,
        default = RESOURCE_STATUS_TOBEACTIVE
    ) 
    statusreason = models.CharField(max_length=128, blank=True)
    notes = models.TextField(blank=True)

    #Members to allow synchronisation
    processed = models.BooleanField(default=False)
    last_processed = models.DateTimeField(blank=True, null=True)
    current_uname = models.CharField(max_length=32, blank=True)

    def save(self, processed_done=False):
        self.processed = processed_done
        super(User, self).save()

    def __unicode__(self):
        return self.uname + " - " + self.fullname

class BaseResource(models.Model):
    expire = models.DateTimeField(blank=True, null=True)
    owner = models.ForeignKey('User')
    status = models.IntegerField(choices = RESOURCE_STATUSES,
        default = RESOURCE_STATUS_TOBEACTIVE
    ) 
    created = models.DateTimeField(auto_now_add=True)
    modified = models.DateTimeField(auto_now=True)

    #Members to allow synchronisation
    processed = models.BooleanField(default=False)

    class Meta:
        abstract = True

    create_script = None
    update_script = 'default_update.sh'
    def update_args(self):
        delete_args = self.delete_args()
        create_args = self.create_args()
        return [self.delete_script, self.create_script, len(delete_args), len(create_args)] + delete_args + create_args
    suspend_script = None
    delete_script = None

    def save(self, processed_done=False):
        self.processed = processed_done
        super(BaseResource, self).save()

